sciplot.utils package
=====================

Submodules
----------

sciplot.utils.general module
----------------------------

.. automodule:: sciplot.utils.general
    :members:
    :undoc-members:
    :show-inheritance:

sciplot.utils.mplstyle module
-----------------------------

.. automodule:: sciplot.utils.mplstyle
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: sciplot.utils
    :members:
    :undoc-members:
    :show-inheritance:
